@@ -1,17 +1,15 @@
 package Map::Tube::Samara;
 
-# Pragmas.
 use strict;
 use warnings;
 use 5.006;
 
-# Modules.
 use File::Share ':all';
 use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 # Get XML.
 has xml => (
@@ -36,6 +34,7 @@ Map::Tube::Samara - Interface to the Samara Metro Map.
 =head1 SYNOPSIS
 
  use Map::Tube::Samara;
+
  my $obj = Map::Tube::Samara->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
  my $line = $obj->get_line_by_id($line_id);
@@ -117,11 +116,11 @@ For more information about Samara Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE1
 
- # Pragmas.
+=for comment filename=print_samara_route.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Samara;
 
@@ -139,11 +138,11 @@ For more information about Samara Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE2
 
- # Pragmas.
+=for comment filename=print_samara_def_xml_file.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::Samara;
 
  # Object.
@@ -160,11 +159,11 @@ For more information about Samara Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE3
 
- # Pragmas.
+=for comment filename=print_samara_image.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::GraphViz;
  use Map::Tube::GraphViz::Utils qw(node_color_without_label);
  use Map::Tube::Samara;
@@ -190,19 +189,19 @@ For more information about Samara Map, click L<here|https://en.wikipedia.org/wik
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Samara/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Samara/master/images/ex3.png" alt="Самарский метрополитен" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Samara/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Samara/master/images/ex3.png" alt="Самарский метрополитен" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
- # Pragmas.
+=for comment filename=print_samara_lines.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Samara;
 
@@ -220,11 +219,11 @@ For more information about Samara Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE5
 
- # Pragmas.
+=for comment filename=print_samara_line_stations.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Samara;
 
@@ -288,7 +287,7 @@ Install the Map::Tube concrete metro modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Map-Tube-Samara>
+L<https://github.com/michal-josef-spacek/Map-Tube-Samara>
 
 =head1 AUTHOR
 
@@ -298,12 +297,14 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2017 Michal Josef Špaček
- Artistic License
- BSD 2-Clause License
+© 2014-2025 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.07
+0.08
 
 =cut
